import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
grandparentdir =  os.path.dirname(parentdir)
sys.path.insert(0, grandparentdir)

import title_rc
from main_paras import getMainTopLeft
import main_paras
from profile_detail.profile_detail import _ProfileDetail
from sign_detail.sign_in import _SignIn
from profile_detail.test_report import _TestReport
from wrong_password import _WrongPassword


class _ProfileDialog(QtWidgets.QDialog):
    def __init__(self,parent=None):
        super(_ProfileDialog, self).__init__(parent)


        loadUi(os.path.join(currentdir,'profile_wrap.ui'),self)
        self.config()
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        self.setWindowFlags(flags)
        self.setAttribute(QtCore.Qt.WA_TranslucentBackground)
        self.resize(93, 89)
        

    def closeEvent(self,event):
        print("_ProfileDialog is closing")

    def config(self):
        try:
            self.profile_bt.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.profile_bt.clicked.connect(self.profile_hook)

            self.report_bt.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.report_bt.clicked.connect(self.report_hook)

            self.sign_bt.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.sign_bt.clicked.connect(self.sign_hook)

            if main_paras.sign_in_token !='':
                self.sign_bt.setText(self.tr('Sign Out'))
            else:
                self.sign_bt.setText(self.tr('Sign In'))
        
            pass
        except Exception as error:
            print(error)

    def profile_hook(self):
        try:
            #global popUp
            self.close()
            popUp = _ProfileDetail()
            x,y = getMainTopLeft()
            popUp.move(x,y)
            popUp.exec()
            pass
        except Exception as error:
            print(error)

    def report_hook(self):
        try:
            global popUp
            self.close()
            if main_paras.sign_in_token !='':
                popUp = _TestReport()
            else:
                popUp = _WrongPassword()
                popUp.setMessage(self.tr("Sign In first."),self.tr('Ok'))
                
            x,y = getMainTopLeft()
            popUp.move(x,y)
            popUp.show()
                
        except Exception as error:
            print(error)

    def sign_hook(self):
        try:
            if main_paras.sign_in_token =='':
                global popUp
                self.close()
                popUp = _SignIn()
                x,y = getMainTopLeft()
                popUp.move(x,y)
                popUp.show()
            else:
                main_paras.sign_in_user =''
                main_paras.sign_in_token =''
                main_paras.test_place =''
                main_paras.test_city  =''
                main_paras.test_country =''
                main_paras.test_provider =''
                main_paras.report_email_1 =''
                main_paras.report_email_2 =''
                self.sign_bt.setText(self.tr('Sign In'))
                
        except Exception as error:
            print(error)

            

if __name__ == "__main__":
    from PyQt5.QtCore import QTranslator
    import sys
##    trans=QTranslator()
##    trans.load("setting_wrap.qm")
    
    os.environ["QT_IM_MODULE"] = "qtvirtualkeyboard"

    
    app = QtWidgets.QApplication(sys.argv)
##    app.installTranslator(trans)

    QtWidgets.QMainWindow
    window=_ProfileDialog()
    window.show()
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)



import queue
class NonBlockQue():
    def __init__(self):
        self.nQue=queue.Queue()
    def put(self, item):
        self.nQue.put(item, True, 0.01)        
    def get(self):  
        try:
            data = self.nQue.get(True, 0.01)
        except queue.Empty:
            data = None
        return data
    def getTimeout(self, timeout):  
        try:
            data = self.nQue.get(True, timeout)
        except queue.Empty:
            data = None
        return data
    def clear(self):
        self.nQue.queue.clear()



import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
grandparentdir =  os.path.dirname(parentdir)
sys.path.insert(0, grandparentdir)

import title_rc

from whatis_wrap import _Whatis
from play import _Play
from version import version

class _HelpDialog(QtWidgets.QDialog):
    def __init__(self,parent=None):
        super(_HelpDialog, self).__init__(parent)


        loadUi(os.path.join(currentdir,'help.ui'),self)
        self.config()
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        self.setWindowFlags(flags)
        
#        self.exec()

    def closeEvent(self,event):
        print("Pop dialog is closing")

    def config(self):
        try:
            
            self.play_button.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.whatis.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.more.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.faq_button.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.legal.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.contact.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
#            QtWidgets.qApp.focusChanged.connect(self.on_focusChanged)

            self.play_button.clicked.connect(self.play_button_hook)
            self.whatis.clicked.connect(self.open_whatis)
            self.more.clicked.connect(self.open_more)
            self.faq_button.clicked.connect(self.open_faq)
            self.legal.clicked.connect(self.open_legal)
            self.contact.clicked.connect(self.open_contact)

            self.back.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.back.clicked.connect(self.close)

            pass
        except Exception as error:
            print(error)

    def open_sub_window(self, title, html_file):
        sub_window = _Whatis(title, html_file)
        sub_window.move(self.geometry().x(), self.geometry().y())
        sub_window.exec()
        
    def open_whatis(self):
        self.open_sub_window('Look Spot II '+version, '/home/pi/app/spotii/launcher/comming.html')
    def open_more(self):
        self.open_sub_window(self.tr('More Information'), '/home/pi/app/spotii/launcher/comming.html')
    def open_faq(self):
        self.open_sub_window(self.tr('FAQ'), '/home/pi/app/spotii/launcher/comming.html')
    def open_legal(self):
        self.open_sub_window(self.tr('Legal Notice and Privacy Policy'), '/home/pi/app/spotii/launcher/legal.html')
    def open_contact(self):
        self.open_sub_window(self.tr('Contact Us'), '/home/pi/app/spotii/launcher/contact.html')

    def play_button_hook(self):
        play_window = _Play()
        play_window.move(0,0)
        play_window.exec()
        
##    def on_focusChanged(self):
##        print('focus changed')

if __name__ == "__main__":
    import sys
    
    app = QtWidgets.QApplication(sys.argv)

    QtWidgets.QMainWindow
##    drtn=_HelpDialog().exec()
##    print('pop dialog end',drtn)
    window=_HelpDialog()
    window.show()
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)



import os
import time
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
grandparentdir = os.path.dirname(parentdir)
sys.path.insert(0, grandparentdir)
import title_rc

        
class _Whatis(QtWidgets.QDialog):
    def __init__(self,title,html,parent=None):
        super(_Whatis, self).__init__(parent)
        self.html=html
        loadUi(os.path.join(currentdir,'whatis.ui'),self)
        self.title.setText(title)
        self.config()
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        self.setWindowFlags(flags)
        self.show_html(self.html)

    def config(self):
        try:
            self.back.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.back.clicked.connect(self.close)
#            self.textBrowser.setText('hello')
            
        except Exception as error:
            print(error)

    def show_html(self,html_file):
        try:
            with open(html_file, 'r') as fh:
                self.textBrowser.insertHtml(fh.read())
            QtCore.QTimer.singleShot(0, self.setTextBrowserTop)
        except Exception as error:
            print(error)
        
    def setTextBrowserTop(self):
        vBar=self.textBrowser.verticalScrollBar()
        vBar.setValue(0)


if __name__ == "__main__":
    import sys
    
    app = QtWidgets.QApplication(sys.argv)

    QtWidgets.QMainWindow
    whatis=_Whatis('Legal',os.path.join(currentdir,'legal.html'))
    
    drtn=whatis.exec()
    print('pop dialog end',drtn)
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)




#from PySide2 import QtCore, QtGui, QtWidgets
from PyQt5 import QtCore, QtGui, QtWidgets
import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)

import main_paras

def handleVisibleChanged():
    
    if not QtGui.QGuiApplication.inputMethod().isVisible():
        print('keybord close')
        return
    print('keybord up')
    main_paras.keyboard_up.signal.emit('keyboard')
    for w in QtGui.QGuiApplication.allWindows():
        if w.metaObject().className() == "QtVirtualKeyboard::InputView":
            keyboard = w.findChild(QtCore.QObject, "keyboard")
            if keyboard is not None:
                r = w.geometry()
                r.moveTop(keyboard.property("y"))
                w.setMask(QtGui.QRegion(r))
                return


def main():
    os.environ["QT_IM_MODULE"] = "qtvirtualkeyboard"
    app = QtWidgets.QApplication(sys.argv)

    QtGui.QGuiApplication.inputMethod().visibleChanged.connect(handleVisibleChanged)

    w = QtWidgets.QLineEdit()
    w.show()
    sys.exit(app.exec_())


if __name__ == "__main__":
    main()
    



import json
import os
import requests
import threading
import time
import sys
import queue
#sys.path.append('/home/pi/gxf/python/spotii')
#sys.path.append('/home/pi/gxf/python/spotii/test_chip_handler')

from communication.send_result import SendResult
from define import *
import main_paras



recordId=[None,None,None,None,None]

class WebApi(threading.Thread):
    def __init__(self, *args):             # self, imageFile, image-identifier, queue
        threading.Thread.__init__(self)
        self.imageFile = args[0]
        self.notifyQue = args[1]
        self.passToken = args[2]
        self.address   = args[3]
        
        
        self.fileName   = self.imageFile.split('/')[-1]
        keyList         = self.fileName.split('_')
        self.cassetteId = keyList[0]
        self.slotNo     = int(keyList[1])
        self.photoIndex = int(keyList[2])
        self.timeStamp  = int(keyList[3])

#qForGui format: [device_index, retCode, QRcode, message]
        
    def addTest(self):
        
        service = "/ctestlookspot/addtest"
        url  = baseUrl+service
        payload = json.dumps({
          "passtoken": self.passToken,
          "testid": self.cassetteId,
          "place": self.address[0],
          "city": self.address[1],
          "country": self.address[2],
          "timestamp": str(self.timeStamp)+'000',
          "mode": main_paras.test_mode,
          "localdate": time.strftime("%d/%m/%Y",time.localtime(self.timeStamp)),
          "localtime": time.strftime("%H:%M:%S",time.localtime(self.timeStamp)),
          "readerserial": main_paras.serial
        })
        headers = {
          'Authorization': 'Basic bGFpcGFjOmxhaXBhY3dz',
          'Content-Type': 'application/json'
        }
        print('addTest')
        print(payload)
        response = requests.request("POST", url, headers=headers, data=payload)
        
        print(response.text)
        
        
#         service = "/ctestlookspot/addtest?"
#         keys = "&testid="+self.cassetteId+ "&place="+self.address[0]+ "&city="+self.address[1]+ "&country="+self.address[2]+"&timestamp="+\
#         str(self.timeStamp)+'000'+"&mode=speed"+\
#         "&localdate="+time.strftime("%d/%m/%Y",time.localtime(self.timeStamp))+\
#         "&localtime="+time.strftime("%H:%M:%S",time.localtime(self.timeStamp))+\
#         "&readerserial="+SERIAL_NO
#         url = baseUrl+service+self.client+keys
#         #print("addtest",url)
#         payload  = {}
#         headers  = {}
#         response = requests.request("POST", url, headers=headers, data=payload)
        
        parsing=json.loads(response.text)
        if parsing[CODE] == RESPONSE_SUCCESS:
            return parsing[RSLT][RCID]
        return None
        

    def uploadImage(self):
        if self.photoIndex == 0:
            imageIndex=self.photoIndex
        else:
            imageIndex=self.photoIndex-1

        service = "/testimagelookspot/upload"
        url = baseUrl + service
        payload={'passtoken': self.passToken,
        'lstestrecordid': str(recordId[self.slotNo]),
        'lstestid': self.cassetteId,
        'imageindex': str(imageIndex)}
        files=[
          ('uploadimage',(self.fileName,open(self.imageFile,'rb'),'image/jpeg'))
        ]
        headers = {
          'Authorization': 'Basic bGFpcGFjOmxhaXBhY3dz'
        }
        
        print('uploadImage')
        print(payload)
        response = requests.request("POST", url, headers=headers, data=payload, files=files)
        
        print(response.text)
        
        
        
        
        
#         service = "/testimagelookspot/upload?"
#         if self.photoIndex == 0:
#             imageIndex=self.photoIndex
#         else:
#             imageIndex=self.photoIndex-1
#         keys = "&lstestrecordid="+ str(recordId[self.slotNo])+"&lstestid="+self.cassetteId+"&imageindex="+ str(imageIndex)
#         url = baseUrl+service+self.client+keys
#         #url = "https://www.locationnow.com/lnservices/ws/testimagelookspot/upload?client=laipac&signature=laipacws&passtoken=1b9f3867298b394a&lstestrecordid=6118&lstestid=La0000888&imageindex=0"
#         payload={}
#         files=[
#           ('uploadimage',(self.fileName,open(self.imageFile,'rb'),'image/jpeg'))
#         ]
#         headers = {}
#         response = requests.request("POST", url, headers=headers, data=payload, files=files)        
#         print(response.text)
        
        parsing=json.loads(response.text)
        if parsing[CODE] == RESPONSE_SUCCESS:                            
            self.notifyQue.put([self.slotNo, int(parsing[RSLT][RCODE]), self.cassetteId, parsing[RSLT][MSSG], recordId[self.slotNo]])
        os.remove(self.imageFile)        
        return None

    def run(self):
        if recordId[self.slotNo] == None or self.photoIndex == 0:
            recordId[self.slotNo]=self.addTest()
                        
        if recordId[self.slotNo] == None:
            self.notifyQue.put([self.slotNo, -1, "Retry", "Add test Fail"])
            return
        
        print('web api run',recordId)
        self.uploadImage()
    
def sendToApi(imageFile, notifyQue, passToken, address): # uploading imagefile name and test result share same queue, file name is string, test result is a list.
    if type(imageFile) ==str:
        webApi=WebApi(IMG_PATH+imageFile, notifyQue, passToken, address)
        webApi.start()
    else:
        sendResult=SendResult(imageFile, passToken)
        sendResult.start()
    
def sendToApi_test():
    imageFile = "La0000835_0_0_1615836967_20210315153607.jpg"
    notifyQue=queue.Queue()
    passToken = "111111111111"
    sendToApi(imageFile, notifyQue, passToken, ADDRESS)
    
def time_test():
    print(time.gmtime())
    t=time.time()
    print(time.gmtime(t))
    print(time.strftime("%b %d %Y %H:%M:%S", time.gmtime(t)))
    print(time.strftime("%b %d %Y %H:%M:%S", time.localtime(t)))
    print(time.strftime("%d/%m/%Y", time.localtime(t)))
    print(time.strftime("%H:%M:%S", time.localtime(t)))

if __name__ == "__main__":
    #sendToApi_test()
    time_test()



import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi
import time
import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
from SlotPage import SlotPage
import title_rc
from emit_thread import SignalThread
#from main_paras import mainChannelNotify, getDetectionMode
from main_paras import mainChannelNotify, getDetectionMode, setOperation
from main_paras import queueForGui, queueForResult, queueForCom
#from test_handler.cassette_polling import CassettePolling
from define import *
import main_paras


class PageResponse(QtCore.QThread):
    signal = QtCore.pyqtSignal(object)



class MyStackedWidget(QtWidgets.QStackedWidget):
    def __init__(self,parent=None):
        super(MyStackedWidget, self).__init__(parent)
        self.button_hooks=[None,None,None,None,None,None,self.scanHook,self.flipHook,self.invalidQrHook]
        
        self.slotBasic = [
           ('empty.png',     None,                self.empty,),
           ('detecting.png', None,                self.warning,),
           ('warning.png',   None,                self.detecting,),
           ('positive.png',  None,                self.positive,),
           ('negative.png',  None,                self.negative,),
           ('invalid.png',   None,                self.invalid,),
           ('scan.png',      self.scanHook,       self.scan,),
           ('flip.png',      self.flipHook,       self.flip,),
           ('invalid_qr.png',self.invalidQrHook,  self.invalid_qr,),
            ]
        self.slot_no = 0
        self.cassetteId=""
        self.timeLeft = TIMER_DURATION
        self.myTimer = QtCore.QTimer()
        self.myTimer.timeout.connect(self.timer_timeout)
        
        self.ready=False
        self.i2c=None
        self.camera=None
        self.function=None
#         self.pageResponse = PageResponse()
#         self.pageResponse.signal.connect(self.emitHook)
        self.pageParking = SignalThread()
        self.pollingTimer=QtCore.QTimer()
        self.pollingTimer.timeout.connect(self.polling_repeat)
        
        loadUi(os.path.join(currentdir,'myStackedWidget.ui'),self)
        self.config()
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
        self.setWindowFlags(flags)
        self.resize(96, 224)
        
        
    def polling_repeat(self):
        self.pageParking.signal.emit(time.time())
        #print(self.slot_no, time.time(),self.pageParking.signal)
        self.pollingTimer.start(1000)
        
        
    def empty(self, item):
        print(self.slot_no, 'empty', item)
    def warning(self, item):
        print(self.slot_no, 'warning', item)
    def detecting(self, item):
        print(self.slot_no, 'detecting', item)
    def positive(self, item):
        print(self.slot_no, 'positive', item)
    def negative(self, item):
        print(self.slot_no, 'negative', item)
    def invalid(self, item):
        print(self.slot_no, 'invalid', item)
    def scan(self, item):
        print(self.slot_no, 'scan', item)
    def flip(self, item):
        print(self.slot_no, 'flip', item)
    def invalid_qr(self, item):
        print(self.slot_no, 'invalid_qr', item)
        
    def scanHook(self):
        print('scanHook')
        if main_paras.sign_in_token == '':
            main_paras.queueForGui.put([SIGN_IN_FIRST_INDEX,'','',''])
            return
        setOperation(self.slot_no ,MANUAL_OPERATION_SCAN)
    def flipHook(self):
        print('flipHook')
        setOperation(self.slot_no ,MANUAL_OPERATION_START_TESTING)
    def invalidQrHook(self):
        print('invalidQrHook')
        setOperation(self.slot_no ,MANUAL_OPERATION_START)

    def setSlotNo(self,number):
        try:
            assert(number >= 0 and number <=4), "Wrong slot number"
            self.slot_no = number
            for page in range(0, len(self.slotBasic)):
                self.setCurrentIndex(page)
                self.currentWidget().setDetail(self.slot_no, page)
                style = '.QWidget{background-image:url(:/slot/png/slot/'+self.slotBasic[page][0]+ ');border:0px}'
                self.currentWidget().background.setStyleSheet(style)
                self.currentWidget().buttonHook(self.slotBasic[page][1])
            self.ready=True
            
            self.setCurrentIndex(0)
            #self.pollingTimer.start()
        except Exception as error:
            print(error)
        except AssertionError as e:
            raise Exception( e.args )

    def config(self):
        try:
            #self.currentChanged.connect(self.onChanged)
            pass
        except Exception as error:
            print(error)

#     def emitHook(self,item):
#         try:
#             print(time.strftime('%Y%m%d%H%M%S'),"emitHook:",item)
#             slotNo  = item[0]
#             errCode = item[1]
#             qrCode  = item[2]
#             if slotNo == NON_SLOT_INDEX:
#                 for i in range(TOTAL_SLOTS):
#                     self.setStatus(SLOT_STATUS_WARNING, 'CR Error')
#             elif errCode == DEVICE_STATE_TAKING_PHOTO:
#                 self.detecting_(qrCode)
#             elif errCode == Positive_test_result:
#                 self.setStatus(SLOT_STATUS_POSITIVE, qrCode)
#             elif errCode == Negative_test_result:
#                 self.setStatus(SLOT_STATUS_NEGATIVE, qrCode)
#             elif errCode == Invalid_image_identifier:
#                 self.setStatus(SLOT_STATUS_INVALID, qrCode)
#             elif errCode == DEVICE_STATE_CASSETTE_EMPTY:
#                 self.setStatus(SLOT_STATUS_EMPTY, qrCode)
#             else:
#                 self.setStatus(SLOT_STATUS_WARNING, qrCode)
#         except Exception as e:
#             print(e)
    def setStatus(self, status_index, cassette, time=None):
        try:
            
            
            self.cassetteId=cassette
            self.setCurrentIndex(status_index)
            page=self.currentWidget()
            page.id.setText(self.cassetteId)
            if(time!=None):
                page.timer.setText(time) ## 1 for counting down timer
            else:
                self.myTimer.stop()
        except Exception as e:
            print (e)

    def detecting_(self, cassette):
        try:
            self.cassetteId=cassette
            self.timeLeft = TIMER_DURATION
            self.myTimer.start(1000)
            self.showDetecting()
        except Exception as e:
            print(e)

    def timer_timeout(self):
        try:
            self.timeLeft -= 1
            self.showDetecting()        
            if self.timeLeft == 0:
                self.detection_timeout()
                self.myTimer.stop()
        except Exception as e:
            print(e)
        
    def showDetecting(self):
        try:
            self.setStatus(SLOT_STATUS_DETECTING, self.cassetteId, time.strftime('%M:%S', time.gmtime(self.timeLeft)))
        except Exception as e:
            print(e)
    def detection_timeout(self):
        try:
            self.setStatus(SLOT_STATUS_WARNING, self.cassetteId)
        except Exception as e:
            print(e)

    def onChanged(self, index):
        if self.ready :
            try:
                self.pageParking.signal.disconnect()
            except Exception:
                pass
            self.pageParking.signal.connect(self.slotBasic[index][2])
            
    def totalPage(self):
        return len(self.slotBasic)

if __name__ == "__main__":
    import sys
    
    app = QtWidgets.QApplication(sys.argv)

    QtWidgets.QMainWindow
    window=MyStackedWidget()
    window.show()
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)




import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
#parentdir = os.path.dirname(currentdir)
#sys.path.insert(0, parentdir)
sys.path.insert(0, currentdir)
#from emit_thread import _EmitThread
#from channel import Channel
from non_block_queue import NonBlockQue
from define import *

import queue

queueForGui=queue.Queue()
queueForCom=queue.Queue()
queueForResult=queue.Queue()


TITLE_HIGH = 48
MAIN_X = 0
MAIN_Y = 0
def getMainTopLeft():
    return MAIN_X, MAIN_Y
def setMainTopLeft(x,y):
    global MAIN_X
    global MAIN_Y
    MAIN_X = x
    MAIN_Y = y + TITLE_HIGH

##from PyQt5 import QtCore
##signal = QtCore.pyqtSignal(object)
##def mainChannelStart(hook):
##    global signal
##    signal.connect(hook)
##def mainChannelNotify(item):
##    signal.emit(item)


from PyQt5 import QtCore
class _EmitThread(QtCore.QThread):
    signal = QtCore.pyqtSignal(object)

main_ui_channel=_EmitThread()
def mainChannelStart(hook):
    global main_ui_channel
    main_ui_channel.signal.connect(hook)
#    main_ui_channel.start()
def mainChannelNotify(item):
    main_ui_channel.signal.emit(item)


        
keyboard_up = _EmitThread()

#     try:
#         data = some_queue.get(False)
#         # If `False`, the program is not blocked. `Queue.Empty` is thrown if
#         # the queue is empty
#     except Queue.Empty:
#         data = None

manual_command_que = NonBlockQue()
api_result_que = NonBlockQue()
type_in_que = NonBlockQue()

# toGui=Channel()
# toCom=Channel()
# forResult=Channel()
# 

manual_operation = [MANUAL_OPERATION_START,MANUAL_OPERATION_START,MANUAL_OPERATION_START,MANUAL_OPERATION_START,MANUAL_OPERATION_START]# for manual command setting sequence
def setOperation(index, operation):
    manual_operation[index] = operation
def getOperation(index):
    return manual_operation[index]

decMode = CASSETTE_DETECTION_MODE_AUTO #for different cassette identify mode base on cassette type
def setDetectionMode(mode):
    global decMode
    decMode=mode
    if decMode == CASSETTE_DETECTION_MODE_MANUAL:
        for i in range(0, TOTAL_SLOTS):
            setOperation(i, MANUAL_OPERATION_START)
def getDetectionMode():
    return decMode

test_mode = 'speed'
testMode = TEST_MODE_SPEED
def setTestMode(mode):
    global testMode
    global test_mode
    testMode=mode
    if testMode == TEST_MODE_SPEED:
        test_mode = 'speed'
    else:
        test_mode = 'normal'
        
def getTestMode():
    return testMode
sign_in_user =''
sign_in_token =''
test_place =''
test_city  =''
test_country =''
test_provider =''
report_email_1 =''
report_email_2 =''
serial=''

    



import json
import os
import requests
import threading
import time
import sys
import queue

from define import *

from main_paras import api_result_que
class SignIn(threading.Thread):
    def __init__(self, *args):             # self, imageFile, image-identifier, queue
        threading.Thread.__init__(self)
        self.notifyQue = args[0]
        self.user = args[1]
        self.password = args[2]
#qForGui format: [device_index, retCode, QRcode, message]
    def run(self):
        excReason=''
        api_result_que.clear()
        for i in range(API_RETRY_TIME):
            try:
                service = "/signinlookspot"
                url = baseUrl + service
                payload = json.dumps({
#                   "userid": "feng.gao@laipac.com",
#                   "password": "123456"
                  "userid": self.user,
                  "password": self.password
                })
                
                
                headers = {
                  'Authorization': 'Basic bGFpcGFjOmxhaXBhY3dz',
                  'Content-Type': 'application/json'
                }
                response = requests.request("POST", url, headers=headers, data=payload)
                print(response.text)
                parsing=json.loads(response.text)
                if parsing[CODE] == RESPONSE_SUCCESS:
                    self.notifyQue.put( [NON_SLOT_INDEX, SIGN_IN_SUCCESS, parsing[RSLT][TKEN], ''] )
                    api_result_que.put( [NON_SLOT_INDEX, SIGN_IN_SUCCESS, parsing[RSLT][TKEN], ''] )
                else:
                    self.notifyQue.put( [NON_SLOT_INDEX, SIGN_IN_FAIL,  parsing[CODE], parsing[DESC]] )
                    api_result_que.put( [NON_SLOT_INDEX, SIGN_IN_FAIL,  parsing[CODE], parsing[DESC]] )
                return
            except Exception as e:
                excReason = "signInException"
                print(e)
            time.sleep(API_RETRY_SLEEP)
            
        else:
            self.notifyQue.put( [NON_SLOT_INDEX, SIGN_IN_FAIL,  excReason, ''] )
            api_result_que.put( [NON_SLOT_INDEX, SIGN_IN_FAIL,  excReason, ''] )
            
def signIn_test():
    notifyQue=queue.Queue()
    signIn=SignIn(notifyQue)
    signIn.start()
    
    while True:
        notify = notifyQue.get()
        print(notify)
        notifyQue.task_done()
        time.sleep(0.1)
        if not signIn.is_alive():
            break;
    print("sign in done")
    

if __name__ == "__main__":
    signIn_test()    



import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi
import subprocess
import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
grandparentdir =  os.path.dirname(parentdir)
sys.path.insert(0, grandparentdir)


import title_rc
from main_paras import getMainTopLeft

class _Volume(QtWidgets.QDialog):
    def __init__(self,parent=None):
        super(_Volume, self).__init__(parent)


        self.volumeHold = 0
        loadUi(os.path.join(currentdir,'volume.ui'),self)
        self.config()
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        self.setWindowFlags(flags)
        self.setAttribute(QtCore.Qt.WA_TranslucentBackground)
        self.resize(146, 62)
        

    def closeEvent(self,event):
        try:
            if self.mute.isChecked():
                setVolume = self.volumeHold
            else:
                setVolume = self.slider.value()
            cmd = 'amixer set \'Master\''+' '+str(setVolume)+'%'
            print(cmd)
            subprocess.run([cmd], shell=True)
        except Exception as e:
            print(e)
        print("_Volume is closing")

    def config(self):
        try:
            self.mute.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.slider.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.mute.clicked.connect(self.mute_hook)
            self.slider.valueChanged.connect(self.slider_hook)
            
            result=subprocess.check_output(['amixer']).decode('utf-8').replace('\r','')
            result = result.split('Simple mixer control')
            
            gotMaster=False
            for each in result:
                if 'Master' in each:
                    gotMaster = True
                    break;
                
            volume = 100
            if gotMaster:
                #print(each)
                paraList = each.split('\n')
                #print (paraList)
                for item in paraList:
                    if 'Front Left:' in item:
                        volume = int(item[item.find('[')+1: item.find('%')])
                        print (volume)
            self.slider.setValue(volume)
            
        
            pass
        except Exception as error:
            print(error)

    def mute_hook(self):
        try:
            if self.mute.isChecked():
                self.volumeHold=self.slider.value()
                self.slider.setValue(0)
                #print('Mute')
            else:
                #print('UnMute')
                self.slider.setValue(self.volumeHold)
            pass
        except Exception as error:
            print(error)

    def slider_hook(self, value):
        try:
            pass
        except Exception as error:
            print(error)            
##    def on_focusChanged(self):
##        print('focus changed')

if __name__ == "__main__":
    from PyQt5.QtCore import QTranslator
    import sys
    
    app = QtWidgets.QApplication(sys.argv)
    window=_Volume()
    window.show()
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)



import cv2

def qrIdentify(image):
    decoder = cv2.QRCodeDetector()
    value, points, _ = decoder.detectAndDecode(image)
    print(value)
    try:
        print(points)
        if points.any() == None:
            print('qr')
    except Exception as e:
        return None

    return value



import cv2
import os
import random
import ntpath

from PIL import Image
import piexif


ROW = 0
COL = 1


CROP_HEIGHT = 285
CROP_WIDTH  = 740

EXTEND = 200


IDEAL_BAR_ROW_OFFSET  = 90
IDEAL_BAR_COL_OFFSET  = 280

IDEAL_BAR_WIDTH = 40
IDEAL_BAR_HEIGHT = 105


FIRST_CROP_ROW =460
FIRST_CROP_COL =215

CROP_TOP    =[FIRST_CROP_ROW, FIRST_CROP_COL]
CROP_BOTTOM =[FIRST_CROP_ROW+CROP_HEIGHT+EXTEND, FIRST_CROP_COL+CROP_WIDTH]





SAMPLE_PIXELS = [[1,1], [100,100], [200,200]]


TOP    = [0, IDEAL_BAR_COL_OFFSET - 150]   # row, col
BOTTOM = [CROP_HEIGHT+EXTEND, IDEAL_BAR_COL_OFFSET + 240] # the range is from TOP  to [BOTTOM[ROW-1], BOTTOM[COL-1]]

TARGET = [20, 10]   # height, width
TARGET_HEIGHT = 20
TARGET_WIDTH  = 10


HEIGHT = 0
WIDTH  =1

def isLine(img, begin, end):
    for c in range(begin[COL], end[COL]):
        if img[begin[ROW], c] !=0:
            return False
    return True
def isBlock(img, top, bottom):
    for r in range(top[ROW], bottom[ROW]):
        if not isLine(img, [r, top[COL]], [r, bottom[COL]]):
            return False
    return True

def findTarget(img, top, bottom, target):
    finalRow = -1
    finalCol = -1
    
    print(top, bottom)

    for c in range(top[COL], bottom[COL] - target[WIDTH]):
        if finalCol != -1:
            break;
        for r in range(top[ROW], bottom[ROW] - target[HEIGHT]):
            if isBlock(img, [r, c], [r+target[HEIGHT], c+target[WIDTH]]):
                finalCol = c
                break;
    
    if finalCol == -1:
        return -1,-1

    print("got col offset ", finalCol)
    middleR =r-(IDEAL_BAR_HEIGHT-target[HEIGHT])
    print("middle r ", middleR)
    for r in range(middleR,  middleR+ (IDEAL_BAR_HEIGHT-target[HEIGHT]) +1):
        if finalRow != -1:
            break;
        for c in range(finalCol, finalCol+IDEAL_BAR_WIDTH-target[WIDTH]):
            if isBlock(img, [r, c], [r+target[HEIGHT], c+target[WIDTH]]):
                finalRow = r
                break;

    return finalRow, finalCol

# def findTarget(img, top, bottom, target):
#     finalRow = -1
#     finalCol = -1
#     
#     for c in range(top[COL], bottom[COL] - target[WIDTH]):
#         for r in range(top[ROW], bottom[ROW] - target[HEIGHT]):
#             if isBlock(img, [r, c], [r+target[HEIGHT], c+target[WIDTH]]):
#                 finalCol = c
#                 finalRow = r
#                 break;
#     
#     return finalRow, finalCol

def calibration(img):
    try:
        gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
        thresh = cv2.threshold(gray, 123, 255, cv2.THRESH_BINARY)[1]
        kernel = cv2.getStructuringElement(cv2.MORPH_ELLIPSE, (7,7))
        morph = cv2.morphologyEx(thresh, cv2.MORPH_OPEN, kernel)
        letter = morph.copy()
        finalRow, finalCol = findTarget(letter, TOP, BOTTOM, TARGET)
    except Exception as e:
        print ("calibration exception: ",e)
        finalRow, finalCol =-1, -1
    
    if finalRow == -1 or finalCol == -1:
        print("calibration failed!")
        finalRow, finalCol =IDEAL_BAR_ROW_OFFSET+EXTEND, IDEAL_BAR_COL_OFFSET
    return finalRow, finalCol
    

def crop_rotate(img, imageFile):
    height, width = img.shape[:2]
    for i in range(10):
        row = random.randint(0, height-1)
        col = random.randint(0, width-1)
        sample =img[row,col]
        #print(row, col, sample)
        if sample[0] != sample[1] or sample[0] != sample[2] or sample[1] != sample[2]:
            break;            
    else:
        print("blank picture for", imageFile.split('/')[-1].split('_')[0], imageFile.split('/')[-1].split('_')[1])
#         blankImageFile=IMG_PATH+"blank_"+imageFile.split('/')[2]
#         cv2.imwrite(blankImageFile,img)
        return False
    
    newImg=cv2.rotate(img,cv2.ROTATE_90_COUNTERCLOCKWISE)
    cropImg=newImg[CROP_TOP[ROW]:CROP_BOTTOM[ROW], CROP_TOP[COL]:CROP_BOTTOM[COL]]
    
#     path, file = ntpath.split(imageFile)
#     originalImage = os.path.join(path, 'original_'+file)
#     cv2.imwrite(originalImage, cropImg) 
    #print(imageFile)
    offsetRow, offsetCol = calibration(cropImg)
    print("offset ", offsetRow, offsetCol)
    detectRow = CROP_TOP[ROW] + offsetRow
    detectCol = CROP_TOP[COL] + offsetCol
    
    newRow = detectRow - IDEAL_BAR_ROW_OFFSET
    newCol = detectCol - IDEAL_BAR_COL_OFFSET
    print("new ", newRow, newCol)
    finalImg=newImg[newRow:newRow+CROP_HEIGHT, newCol:newCol+CROP_WIDTH]
    cv2.imwrite(imageFile, finalImg)
    
    my_exif_ifd = {
                piexif.ExifIFD.CameraOwnerName: u"Spot II",
                }
    exif_dict = {"Exif":my_exif_ifd}
    exif_bytes = piexif.dump(exif_dict)
    im = Image.open(imageFile)
    im.save(imageFile, exif=exif_bytes)
    im.close()
    
    
#    print("Save image to ",imageFile)
    return True
#     gaussianBlurKernel = np.array(([[1, 2, 1], [2, 4, 2], [1, 2, 1]]), np.float32)/9
#     sharpenKernel = np.array(([[0, -1, 0], [-1, 9, -1], [0, -1, 0]]), np.float32)/9
#     meanBlurKernel = np.ones((3, 3), np.float32)/9

#def imageFilter(img):
def imageFilter():
    import cv2
    import numpy as np

    img = cv2.imread("test.jpg")
    img = cv2.resize(img, (0, 0), None, .25, .25)

    gaussianBlurKernel = np.array(([[1, 2, 1], [2, 4, 2], [1, 2, 1]]), np.float32)/9
    sharpenKernel = np.array(([[-1, -4, -2], [2, 18, 2], [-3, -3, -1]]), np.float32)/9
    meanBlurKernel = np.ones((3, 3), np.float32)/9

    gaussianBlur = cv2.filter2D(src=img, kernel=gaussianBlurKernel, ddepth=-1)
    meanBlur = cv2.filter2D(src=img, kernel=meanBlurKernel, ddepth=-1)
    sharpen = cv2.filter2D(src=img, kernel=sharpenKernel, ddepth=-1)

    horizontalStack = np.concatenate((img, gaussianBlur, meanBlur, sharpen), axis=1)

    cv2.imwrite("Output.jpg", horizontalStack)

    cv2.imshow("2D Convolution Example", horizontalStack)

    cv2.waitKey(0)
    #cv2.destroyAllWindow()
    
if __name__ == "__main__":
    imageFilter()




import smbus
import threading
from time import *
#i2c_sem = threading.Semaphore()
class i2c_device:
    def __init__(self, addr, port=1):
        self.addr = addr
        self.bus = smbus.SMBus(port)

# Write a single command
    def write_cmd(self, cmd):
        
        self.bus.write_byte(self.addr, cmd)
        sleep(0.0001)

# Write a command and argument
    def write_cmd_arg(self, cmd, data):
        #i2c_sem.acquire()
        self.bus.write_byte_data(self.addr, cmd, data)
        #i2c_sem.release()
        sleep(0.0001)

# Write a block of data
    def write_block_data(self, cmd, data):
        self.bus.write_block_data(self.addr, cmd, data)
        sleep(0.0001)

# Read a single byte
    def read(self):
        return self.bus.read_byte(self.addr)

# Read
    def read_data(self, cmd):
        return self.bus.read_byte_data(self.addr, cmd)

# Read a block of data
    def read_block_data(self, subAddr, number):
      #return self.bus.read_block_data(self.addr, cmd)
        #i2c_sem.acquire()
        data = self.bus.read_i2c_block_data(self.addr, subAddr, number)
        #i2c_sem.release()
        return data

# SMBUS Read a block of data
    def read_block_data_smbus(self, cmd):
        return self.bus.read_block_data(self.addr, cmd)



import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
##grandparentdir =  os.path.dirname(parentdir)
##sys.path.insert(0, grandparentdir)
##g_g_parentdir = os.path.dirname(grandparentdir)
##sys.path.insert(0, g_g_parentdir)

import title_rc
from main_paras import getMainTopLeft

class _WrongPassword(QtWidgets.QDialog):
    def __init__(self,parent=None):
        super(_WrongPassword, self).__init__(parent)


        loadUi(os.path.join(currentdir,'wrong_password.ui'),self)
        self.config()
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        self.setWindowFlags(flags)
        

    def closeEvent(self,event):
        print("_WrongPassword is closing")
    def setMessage(self,message, button=None):
        #print('in setMessage',message,button)
        self.title.setText(message)
        if(button!=None):
            self.try_bt.setText(button)

    def config(self):
        try:
            self.try_bt.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.try_bt.clicked.connect(self.try_bt_hook)
            pass
        except Exception as error:
            print(error)

    def try_bt_hook(self):
        try:
            self.close()
            pass
        except Exception as error:
            print(error)

if __name__ == "__main__":
    from PyQt5.QtCore import QTranslator
    import sys
##    trans=QTranslator()
##    trans.load("setting_wrap.qm")
    

    
    app = QtWidgets.QApplication(sys.argv)
##    app.installTranslator(trans)

    QtWidgets.QMainWindow
    window=_WrongPassword()
    window.show()
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)



import json
import os
import requests
import threading
import time
import sys
import queue

from define import *

from main_paras import api_result_que
class ChgPsw(threading.Thread):
    def __init__(self, *args):
        threading.Thread.__init__(self)
        self.passToken   = args[0]
        self.password   = args[1]
        self.newPassword  = args[2]
    def run(self):
        excReason=''
        api_result_que.clear()
        for i in range(API_RETRY_TIME):
            try:
                service = "/changepwdlookspot"
                url = baseUrl + service
                payload = json.dumps({
                  "passtoken": self.passToken,
                  "oldpassword": self.password,
                  "newpassword":self.newPassword,
                })
                headers = {
                  'Authorization': 'Basic bGFpcGFjOmxhaXBhY3dz',
                  'Content-Type': 'application/json'
                }
                print(payload)
                response = requests.request("POST", url, headers=headers, data=payload)
                print(response.text)
                parsing=json.loads(response.text)
                if parsing[CODE] == RESPONSE_SUCCESS:
                    api_result_que.put( [NON_SLOT_INDEX, API_RESPONSE_SUCCESS,  parsing[CODE], parsing[RSLT]] )
                else:
                    api_result_que.put( [NON_SLOT_INDEX, API_RESPONSE_FAIL,  parsing[CODE], parsing[RSLT]] )
                return
            except Exception as e:
                excReason = "signUpException"
                print('exception ChgPsw', e)
            time.sleep(API_RETRY_SLEEP)
            
        else:
            print('ChgPsw timeout')
            api_result_que.put( [NON_SLOT_INDEX, API_RESPONSE_FAIL,  excReason, 'time out'] )
            
def test():
    notifyQue=queue.Queue()
    signIn=SignUp(notifyQue)
    signIn.start()
    
    while True:
        notify = notifyQue.get()
        print(notify)
        notifyQue.task_done()
        time.sleep(0.1)
        if not SignUp.is_alive():
            break;
    print("sign up done")
    

if __name__ == "__main__":
    test()    



import os, sys, inspect

import time
import subprocess
import re



keytype = ['Open', 'WPA', 'WPA-Personal', 'WPA2', 'WPA2-Personal', 'Unknown']
##[['BELL710', 'WPA2-Personal', '53%'], ['UCS', 'WPA2-Personal', '57%'],...]
def getList_linux():

    response = subprocess.check_output(["wpa_cli -iwlan0 scan"],shell=True)
    print('scan', response)

    response=''
    for i in range(50):
        response = subprocess.check_output(["wpa_cli -iwlan0 scan_results"],shell=True)
    #print(response)
        response = response.decode("ascii")
    #print(response)    
        response = response.split('\n')
        if len(response)>1 and len(response[1])!=0:
            print('got scan results')
            break;
        print(i)
        time.sleep(0.1)
    simple=[]
    network=[]
    for each in response[1:]:
        item = each.split('\t')
        if len(item)!=5:
            continue
        
        network.append(item[4])
        firstKey=item[3][item[3].find("[")+1:item[3].find("]")]
        if firstKey == 'ESS':
            network.append('Open')
        else:
            network.append('WPA-Personal')
            

        signal = int(item[2])
        if(signal <= -100):
            quality = 0
        elif(signal >= -50):
            quality = 100
        else:
            quality = 2 * (signal + 100);

        network.append(str(quality))
        new =network.copy()
        network.clear()
        if new not in simple:
            simple.append(new)
    print(simple)
    return simple

def connected(interface):
    try:
        command = 'ifconfig '+interface
        response = subprocess.check_output([command],shell=True)
        response = response.decode("ascii")
        r_list   = response.split('\n')
        
        if 'inet ' in r_list[1]:
            return True
        return False
    except Exception as e:
        print(e)
        return False
    
def getProfileList():
    response = subprocess.check_output(["wpa_cli -iwlan0 list_network"],shell=True)
    #print(response)
    response = response.decode("ascii")
    #print(response.split('\n'))
    response = response.split('\n')
    simple=[]
    for each in response:
        item = each.split('\t')
        #print(item)
        if item[0].isdigit():
            #print (item[1])
            simple.append([item[1],item[3]])
    return simple

def gotIndex(ssid):
    p_list = getProfileList()
    try:
        index = 0
        for each in p_list:
            if ssid == each[0]:
                return index
            index += 1
        return None
    except Exception as e:
        print(e)
        return None
        
def deleteProfile(ssid):
    index = gotIndex(ssid)
    if index != None:
        cmd = 'wpa_cli -iwlan0 remove_network '+str(index)
        response = subprocess.check_output([cmd],shell=True)

def disableProfile(index):
    cmd = 'wpa_cli -iwlan0 disable_network '+str(index)
    response = subprocess.check_output([cmd],shell=True)
    print('disable network', index, response)
    
def enableProfile(index):
    cmd = 'wpa_cli -iwlan0 enable_network '+str(index)
    response = subprocess.check_output([cmd],shell=True)
    print('enable network', index, response)
    p_list = getProfileList()
    current = 0
    for each in p_list:
        if current != index and each[1] != '[DISABLED]':
            disableProfile(current)
        current += 1

def addProfile(ssid,key=None):  ##key:    None-- don't change setting, ''-- no key,  others-- key
    index = gotIndex(ssid)
    if key == None:
        return index
    
    if index ==None:        
        response = subprocess.check_output(["wpa_cli -iwlan0 add_network"],shell=True)
        index=int(response.decode("ascii"))
        #print(index)
    cmd = 'wpa_cli -iwlan0 set_network '+str(index)+' ssid \"\\\"'+ssid+'\\\"\"'
    print(cmd)
    subprocess.check_output([cmd],shell=True)
    if(key!=''):
        cmd = 'wpa_cli -iwlan0 set_network '+str(index)+' psk \"\\\"'+key+'\\\"\"'
        subprocess.check_output([cmd],shell=True)
        cmd = 'wpa_cli -iwlan0 set_network '+str(index)+' key_mgmt '+'WPA-PSK'
        subprocess.check_output([cmd],shell=True)
    else:
        cmd = 'wpa_cli -iwlan0 set_network '+str(index)+' key_mgmt '+'NONE'
        subprocess.check_output([cmd],shell=True)
    return index
    
def saveProfile():
    response = subprocess.check_output(["wpa_cli -iwlan0 save"],shell=True)
    print('save profile')
    
    
def killSupplicant(timeout):
    try:
        subprocess.check_output(["sudo killall wpa_supplicant"],shell=True)
        t_0 = time.time()
        while True:
            if not connected('wlan0'):
                return True           
            if time.time() - t_0 > timeout:
                return False
            time.sleep(0.2)
            print(".", end="")        
    except Exception as e:
        print(e)
        return False

def connect_wifi_linux(ssid, key, timeout):  #key:   None--Try to connect with previous setting, ''--No key, others--key
        
    index=addProfile(ssid,key)
    if index ==None :
        return False
    enableProfile(index)
    saveProfile()
    killSupplicant(5)
    time.sleep(2)
    try:
        subprocess.check_output(["sudo wpa_supplicant -Dnl80211 -iwlan0 -c/etc/wpa_supplicant/wpa_supplicant.conf -B"],shell=True)
    except Exception as e:
        print(e)
    
    t_0 = time.time()
    while True:
        if connected('wlan0'):
            return True           
        if time.time() - t_0 > timeout:
            return False
        time.sleep(0.5)
        print(".", end="")
    return True
   ###
    
if __name__ == "__main__":
    #ifconfigStatus('wlan0')
    #killSupplicant(5)
    
    #connect_wifi_linux('TP-Link_LP24','DaReLoVe501',15)
    #connect_wifi_linux('TP-Link_LP24','DaReLoVe501',15)
    #addProfile('TP-Link_LP24','DaReLoVe501')
    #saveProfile()
#    deleteProfile('TP-Link_LP24')
#    saveProfile()
#     print(getProfileList())
#     disableProfile(3)
#     saveProfile()

    getList_linux()




import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
grandparentdir =  os.path.dirname(parentdir)
sys.path.insert(0, grandparentdir)
g_g_parentdir = os.path.dirname(grandparentdir)
sys.path.insert(0, g_g_parentdir)

from define import *
import title_rc
from main_paras import getMainTopLeft
import main_paras
import create_new_account
import wrong_password
from vkeyboard import handleVisibleChanged

class _ForgotPassword(QtWidgets.QDialog):
    def __init__(self,parent=None):
        super(_ForgotPassword, self).__init__(parent)


        loadUi(os.path.join(currentdir,'forgot_password.ui'),self)
        self.config()
#        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
        self.setWindowFlags(flags)
        

    def closeEvent(self,event):
        print("_ForgotPassword is closing")

    def config(self):
        try:
            self.back.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.back.clicked.connect(self.close)
            self.create_account.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.reset_psw_bt.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            
            self.create_account.clicked.connect(self.create_account_hook)
            self.reset_psw_bt.clicked.connect(self.reset_psw_bt_hook)
            pass
        except Exception as error:
            print(error)

    def create_account_hook(self):
        try:
            global popUp
            print('create_account_hook')
            self.close()
            popUp = create_new_account._CreateAccount()
            x,y = getMainTopLeft()
            popUp.move(x,y)
            #popUp.exec()
            popUp.show()
            pass
        except Exception as error:
            print(error)
    def reset_psw_bt_hook(self):
        try:
            global popUp
            popUp = wrong_password._WrongPassword()
            email = self.email.text()
            if email != '' and email.count('@') == 1:
                main_paras.queueForCom.put([FORGOT_PSW, email])
                response=main_paras.api_result_que.getTimeout(10)
                if response == None:
                    popUp.setMessage(self.tr("Check network."))
                elif response[1] == API_RESPONSE_FAIL:
                    popUp.setMessage(self.tr(response[3]))
                elif response[1] == API_RESPONSE_SUCCESS:
                    popUp.setMessage(self.tr("New password sent to email."))
            else:
                popUp.setMessage(self.tr("Enter correct email"))
            x,y = getMainTopLeft()
            popUp.move(x,y)
            popUp.show()
                
        except Exception as error:
            print(error)

if __name__ == "__main__":
    from PyQt5.QtCore import QTranslator
    import sys
##    trans=QTranslator()
##    trans.load("setting_wrap.qm")
    
    os.environ["QT_IM_MODULE"] = "qtvirtualkeyboard"

    
    app = QtWidgets.QApplication(sys.argv)
##    app.installTranslator(trans)
#    QtGui.QGuiApplication.inputMethod().visibleChanged.connect(handleVisibleChanged)


    QtWidgets.QMainWindow
    window=_ForgotPassword()
    window.move(0,0)
    window.show()
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'launcher.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(480, 272)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout.setObjectName("gridLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.progressBar = QtWidgets.QProgressBar(self.centralwidget)
        font = QtGui.QFont()
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.progressBar.setFont(font)
        self.progressBar.setStyleSheet("background-color: rgb(255, 255, 255);\n"
"gridline-color: rgb(0, 255, 0);")
        self.progressBar.setProperty("value", 0)
        self.progressBar.setObjectName("progressBar")
        self.verticalLayout.addWidget(self.progressBar)
        self.label = QtWidgets.QLabel(self.centralwidget)
        font = QtGui.QFont()
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setStyleSheet("background-color: rgb(216, 248, 255);")
        self.label.setText("")
        self.label.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label.setWordWrap(True)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.gridLayout.addLayout(self.verticalLayout, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 480, 26))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Spotii launcher"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())



import os
import sys

import time
import subprocess

from wifi import Cell, Scheme
print (list(Cell.all('wlan0')))

def connect_wifi_linux(ssid, key):
    subprocess.check_output(["sudo su"],shell=True)
    cell=list(Cell.all('wlan0'))[0]
    scheme =Scheme.for_cell('wlan0', 'home', cell, key)
    scheme.save()
    scheme.activate()
    
    
if __name__ == "__main__":
    connect_wifi_linux('TP-Link_LP24', 'DaReLoVe501')


import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
from define import *
import title_rc
from main_paras import getMainTopLeft
import main_paras
from vkeyboard import handleVisibleChanged

class _Input(QtWidgets.QWidget):
    def __init__(self,parent=None):
        super(_Input, self).__init__(parent)
        
        self.original = True
        self.last_scroll_value=0
        loadUi(os.path.join(currentdir,'input.ui'),self)
        #self.setStyleSheet('.QWidget{background-image: url(:/public/png/public/rectangle.png);border:0px;}')
        self.setStyleSheet('background-color: rgb(5, 11, 126)')
        self.config()
#        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
        self.setWindowFlags(flags)
        


    def keyUp(self):
        print('keyUp got emit')
        if self.original:
            self.original = False
            self.scroll.setVisible(True)
            self.move(0,0)
            self.repaint()
        
    def closeEvent(self,event):
        print("_CreateAccount is closing")

    def config(self):
        try:

            self.scroll.setMaximum(20)
            self.scroll.valueChanged.connect(self.scrolled)
            self.scroll.hide()
            main_paras.keyboard_up.signal.connect(self.keyUp)
            
            pass
        except Exception as error:
            print(error)

    def scrolled(self):
        try:
            diff =(self.last_scroll_value - self.scroll.value())*10
            self.last_scroll_value=self.scroll.value()
            print(self.scroll.value())
            children= self.widget.findChildren(QtWidgets.QWidget)
            for child in children:
                if child != self.scroll:
                    child.move(child.pos().x(),child.pos().y()+diff)
            self.repaint()
        except Exception as error:
            print(error)

if __name__ == "__main__":
    from PyQt5.QtCore import QTranslator
    import sys
    
    os.environ["QT_IM_MODULE"] = "qtvirtualkeyboard"

    
    app = QtWidgets.QApplication(sys.argv)
    QtGui.QGuiApplication.inputMethod().visibleChanged.connect(handleVisibleChanged)

    QtWidgets.QMainWindow
    window=_Input()
    window.show()
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)



import os
import hashlib
from setuptools import setup, find_packages
from spotii.version import version

def calculate_checksum(filenames):
    hash = hashlib.md5()
    for fn in filenames:
        if os.path.isfile(fn):
            hash.update(open(fn, "rb").read())
    return hash.digest()
def md5_for_files(folder):
    files = os.listdir(folder)
    filenames=[]
    #print(os.getcwd())
    for each in files:
        if not each.endswith('.md5'):
            filenames.append(os.path.join(folder,each))
    print(filenames)
    result=calculate_checksum(filenames)

    print(result)
    
    with open(folder+'/'+'chk_sum.md5',"wb") as outfile:
        outfile.write(result)

    with open(folder+'/'+'chk_sum.md5',"rb") as inputfile:
        readBack=inputfile.read()
        print(readBack)
    
md5_for_files(os.path.join(os.getcwd(),'spotii/launcher'))
    
# __packages__ = find_packages(
#     where = 'spotii_project',
# #    include = ['define*',],
# #    exclude = ['additional',]
#     )
#__packages__ = ['spotii'] + __packages__
__packages__=['spotii','spotii.guifolder','spotii.communication','spotii.on_off','spotii.test_handler',
              'spotii.guifolder.help_folder','spotii.guifolder.profile_folder','spotii.guifolder.setting_folder','spotii.guifolder.wifi_folder','spotii.guifolder.volume',
              'spotii.guifolder.profile_folder.profile_detail','spotii.guifolder.profile_folder.sign_detail',
              'spotii.guifolder.setting_folder.brightness','spotii.guifolder.setting_folder.cassette_type',
              ]
#__packages__=['spotii']
print(__packages__)


# _ROOT = os.path.abspath(os.path.dirname(__file__))
# def get_data(path):
#     return os.path.join(_ROOT, 'data', path)

#print get_data('resource1/foo.txt')
print(version)
setup(
    name = "spotii",
    version = version,
    description = "Look Spot II",
    author = 'Laipac',
    author_email = 'feng.gao@laipac.com',
    url = 'https://github.com/gxfca/gitTest',
    packages = __packages__,
#    package_dir ={'spoitii':'spotii'},
    package_data={
        'spotii':[
                    'guifolder/*.ui',
                    'guifolder/help_folder/*.ui',
                    'guifolder/help_folder/*.html',
                    'guifolder/wifi_folder/*.ui',
                    'guifolder/volume/*.ui',
                    'guifolder/profile_folder/*.ui',
                    'guifolder/profile_folder/profile_detail/*.ui',
                    'guifolder/profile_folder/sign_detail/*.ui',
                    'guifolder/setting_folder/*.ui',
                    'guifolder/setting_folder/brightness/*.ui',
                    'guifolder/setting_folder/cassette_type/*.ui',                   
                    'launcher/*',
                  ],
                  },
    entry_points={
    'console_scripts': [
        'spotii=spotii.__main__:spot_main',
    ],
    },
    )



try:
    from gpiozero import Button
    from gpiozero import LED, PWMLED
    import time

    import sys, os, inspect
    currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
    parentdir = os.path.dirname(currentdir)
    sys.path.insert(0, parentdir)

    from define import *

#    fan=LED(FAN_PWM_PIN, active_high=False, initial_value=True)
    fan=PWMLED(FAN_PWM_PIN, active_high=False, initial_value=0, frequency = 100)

    def fanTurnOn(on):
        global fan
        if on:
            fan.value=0.5
        else:
            fan.value=0
    if __name__ == "__main__":
        fanTurnOn(True)
        time.sleep(5)
        fanTurnOn(False)
        time.sleep(5)
        fanTurnOn(True)
        time.sleep(5)
        fanTurnOn(False)
except Exception as e:
    print(e)
    pass
    
    



import sys
import subprocess
import threading
import time
from datetime import datetime,timezone
import queue

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)

from test_handler.i2c_lib import i2c_device
from test_handler.cassette_polling import CassettePolling
from define import *
from main_paras import getTestMode
# from smbus import SMBus
# import sys
# sys.path.append('/home/pi/gxf/python/spotii')
# sys.path.append('/home/pi/gxf/python/spotii/test_chip_handler')
# import subprocess
# import queue
# 
# from mythread import MyThread
# import time
# import threading
# from i2c_lib import i2c_device
# from takePhoto import takePhoto
# from datetime import datetime,timezone
# from define import *

 

I2C                 =0
CAMERA              =1
# part of "v4l2-ctl --list-devices" parsing sample sentence
# USB 2.0M Camera: USB 2.0M Camer (usb-0000:01:00.0-1.1.1):
#     /dev/video0   <------ "0" is second target        ^
#     /dev/video1                                       |________"1" is first target 

def usbCameraFinder(deviceInfo):
    detail=deviceInfo.split('\n\t')
    if 'video' in detail[1]:
        return [ord(detail[0].split(')')[0][-1])-ord('0') -1 , ord(detail[1][-1])-ord('0')]
    return None

#    usbList=subprocess.check_output(['v4l2-ctl','--list-devices']).decode("utf-8").split('usb-0000:01:00.0-1.1.')
def cameraMap(cMap):
    try:
        usbList=subprocess.check_output(['v4l2-ctl','--list-devices']).decode("utf-8").split('(usb-0000:')
    except Exception as e:
        print("cameraMap exception:",e)
        return False
    
    for phase in usbList[1:]:
#        print (phase)
        cameraList=usbCameraFinder(phase)
#        print(cameraList)
        if(cameraList):
            cMap[cameraList[0]][1]=cameraList[1]
    return True

def cameraClr(cMap):
    for each in cMap:
        each[CAMERA]=INVALID_DEVICE_INDEX

def i2cMap(cMap):
    
    phase=subprocess.check_output(['i2cdetect','-y','5']).decode("utf-8").split('50: ')
    i2cList=phase[1].split(' ')
    index = 0
    for each in cMap:
        if i2cList[index] == '--' or int(i2cList[index],16) != each[I2C] :
            each[I2C] = INVALID_DEVICE_INDEX
        index+=1



class TestChipHandlerThread (threading.Thread):
    def __init__(self, threadID, name, qForCom, qForGui, qForResult):
        threading.Thread.__init__(self)
        self.threadID = threadID
        self.name = name
        self.qCom = qForCom
        self.qGui = qForGui
        self.qForResult=qForResult
        self.cassettePolling=[None]*5
        self.i2c=[]
        self.cmrMap=[]
        self.initDone = True
        for addr in I2C_DEVICE:
            self.cmrMap.append([addr, INVALID_DEVICE_INDEX])
        if cameraMap(self.cmrMap)==False:
            self.initDone =False
            return 
        print(self.cmrMap)
        i2cMap(self.cmrMap)
        print(self.cmrMap)
        self.deviceQue=[]
        self.checkingResult=[]  # [[0,0,0,0,0,0,0], ..., [0,0,0,0,0,0,0]] total (I2C_PORT)
                    #
        self.startCheck=[]
        for i in range(I2C_PORT):
            self.deviceQue.append(queue.Queue())
            self.checkingResult.append([])
            self.startCheck.append(False)

# RESULT_SLOT_NUMBER 0
# RESULT_ERROR_CODE  1
# RESULT_CASSETTE_ID 2
# RESULT_TEXT        3
    def checkingStop(self, slotNumber):
        self.startCheck[slotNumber]=False
        self.deviceQue[slotNumber].put(PHOTO_TAKING_STOP)
        
    def checkingStart(self, slotNumber):
        self.startCheck[slotNumber] = True
        self.checkingResult[slotNumber].clear()

    def resultReport(self, result):
        if Negative_test_result == result[RESULT_ERROR_CODE] or Positive_test_result == result[RESULT_ERROR_CODE]:
            self.qCom.put(result)
        print('put result',result)
        self.qGui.put(result)
        
    def putToResultList(self, result):     #There is nothing for RESULT_CASSETTE_ID if message is from sub thread. message from communication must have something on RESULT_CASSETTE_ID 
        #print('in putToResultList', result)
        if result[RESULT_ERROR_CODE] == DEVICE_STATE_TAKING_PHOTO:
            self.checkingStart(result[RESULT_SLOT_NUMBER])
            self.qGui.put(result)
        elif result[RESULT_ERROR_CODE] == DEVICE_STATE_MANUAL_FLIP:
            #print('manual flip')
            self.qGui.put(result)
        elif result[RESULT_ERROR_CODE] == DEVICE_STATE_MANUAL_INVALID_QR:
            self.qGui.put(result)
        elif result[RESULT_CASSETTE_ID] == '':
            self.qGui.put(result)
        elif self.startCheck[result[RESULT_SLOT_NUMBER]] == True:
            
            #print('test mode',getTestMode())
            #if len(self.checkingResult[result[RESULT_SLOT_NUMBER]]) == 0 and (Negative_test_result == result[RESULT_ERROR_CODE] or Positive_test_result == result[RESULT_ERROR_CODE]):
            if getTestMode()==TEST_MODE_SPEED:
                self.resultReport(result)
                self.checkingStop(result[RESULT_SLOT_NUMBER])
                return;
            
            if Negative_test_result == result[RESULT_ERROR_CODE] or Control_area_not_found == result[RESULT_ERROR_CODE] :                                
                self.checkingResult[result[RESULT_SLOT_NUMBER]].append(result)
                if len(self.checkingResult[result[RESULT_SLOT_NUMBER]]) == len(PHOTO_TAKING_GAPS)+1:
                    self.resultReport(result)
                    self.checkingStop(result[RESULT_SLOT_NUMBER])
            elif Positive_test_result == result[RESULT_ERROR_CODE]: 
                for each in self.checkingResult[result[RESULT_SLOT_NUMBER]]:
                    if Positive_test_result == each[RESULT_ERROR_CODE]: ## report if get 2 poisitve result
                        self.resultReport(result)
                        self.checkingStop(result[RESULT_SLOT_NUMBER])
                        break;                   
                self.checkingResult[result[RESULT_SLOT_NUMBER]].append(result)
            else:
                self.checkingStop(result[RESULT_SLOT_NUMBER])
                self.resultReport(result)
                
    def run (self):
        super().run()
        print('test monitor run...')
        
        if self.initDone == False:
            self.qGui.put([NON_SLOT_INDEX, -1 , 'Critical error', 'Critical error'])
            while True:
                None

        for i in range(5):
            self.cassettePolling[i]=CassettePolling(i, self.cmrMap[i][I2C], self.cmrMap[i][CAMERA], self.qForResult, self.qCom, self.deviceQue[i])
            self.cassettePolling[i].start()
        while True:
            result=self.qForResult.get() #[0, 1, 'La0012684', 'Negative']
            
            if result == CLOSE_NOW:
                for i in range(5):
                    self.cassettePolling[i].notify(CLOSE_NOW)
                #for i in range(5):
                self.cassettePolling[0].join()
#                 self.cassettePolling[1].join()
#                 self.cassettePolling[2].join()
#                 self.cassettePolling[3].join()
#                 self.cassettePolling[4].join()
                print('got CLOSE_NOW')
                break;
            else:
                self.putToResultList(result)
            self.qForResult.task_done()
            
def i2cTest():
    data=[1,2,3]
    i2cInstant= i2c_device(0x52,I2C_PORT)
    #receiving=i2cInstant.read_block_data(4,6)
    #print(receiving)
    
#     i2cInstant.write_cmd_arg(I2C_MEM_LED_1, 1)
#     time.sleep(0.005)
    i2cInstant.write_cmd_arg(I2C_MEM_LED_2, 0)
    time.sleep(0.005)
#     i2cInstant.write_cmd_arg(I2C_MEM_UV, 1)

#    i2cInstant.write_cmd_arg(I2C_MEM_FORCE_READ, 1)


#     receiving=i2cInstant.read_data(0)
#     print(''.join('{:02x}'.format(receiving)))
# 
    receiving=i2cInstant.read_data(0)
    print(''.join('{:02x}'.format(receiving)))

    receiving=i2cInstant.read_block_data(I2C_MEM_ID, 12)
    print(''.join('{:02x}'.format(x) for x in receiving))

    receiving=i2cInstant.read_block_data(I2C_MEM_UID, 12)
    print(''.join('{:02x}'.format(x) for x in receiving))
    
    
#     receiving=i2cInstant.read_block_data(I2C_COMMAND_ID, 12)
#     print(''.join('{:02x}'.format(x) for x in receiving))
# 
#     receiving=i2cInstant.read_block_data(I2C_COMMAND_UID, 12)
#     print(''.join('{:02x}'.format(x) for x in receiving))

#    i2cInstant.write_cmd_arg(I2C_COMMAND_SET_BLOCK_NO,6)
#    i2cInstant.write_cmd(I2C_COMMAND_SYSTEM_RESET)
# 
    
def cameraMapTest():
    cmrMap=[]
    for addr in I2C_DEVICE:
        cmrMap.append([addr, INVALID_DEVICE_INDEX])
    
    cameraMap(cmrMap)
    print(cmrMap)
    i2cMap(cmrMap)
    print(cmrMap)

def hubTest(): #for hum SMBUS mode, must set SEL2-SEL0 to 001
#     data=[1,2,3]
#     i2cInstant= i2c_device(0x2C,I2C_PORT)
#     time.sleep(1)
#     receiving=i2cInstant.read_block_data_smbus(0)
#     print(receiving)

        try:
            bus=SMBus(5)
            receiving=bus.read_block_data(0x2C,0)
            print(receiving)
        except:
            print("read error")
            
def threadTest():
    qForGui=queue.Queue()
    qForCom=queue.Queue()
    qForResult=queue.Queue()
    TestMonitor=TestChipHandlerThread(3,"TCH",qForCom, qForGui, qForResult)
    TestMonitor.start()
if __name__ == "__main__":

    threadTest()
#    cameraMapTest()   
#    i2cTest()
#    hubTest();        
        



# from emit_thread import _EmitThread
# class Channel():
#     _thread = _EmitThread()
#     def hook(self, guard):
#         self._thread.signal.connect(guard)
#         self._thread.start()
#     def notify(self, item):
#         self._thread.signal.emit(item)



# from PyQt5 import QtCore
# class Channel(QtCore.QThread):
#     signal = QtCore.pyqtSignal(object)
#     def hook(self, guard):
#         self.signal.connect(guard)
#     def notify(self, item):
#         self.signal.emit(item)



import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
grandparentdir =  os.path.dirname(parentdir)
sys.path.insert(0, grandparentdir)
g_g_parentdir = os.path.dirname(grandparentdir)
sys.path.insert(0, g_g_parentdir)

from define import *
import title_rc
from main_paras import getMainTopLeft
import main_paras
import wrong_password
from vkeyboard import handleVisibleChanged

class _TestReport(QtWidgets.QDialog):
    def __init__(self,parent=None):
        super(_TestReport, self).__init__(parent)


        loadUi(os.path.join(currentdir,'test_report.ui'),self)
        self.config()
#        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
        self.setWindowFlags(flags)
        self.last_scroll_value=0
        self.original = True

    def scrolled(self):
        try:
            diff =(self.last_scroll_value - self.scroll.value())*10
            self.last_scroll_value=self.scroll.value()
            print(self.scroll.value())
            children= self.widget.findChildren(QtWidgets.QWidget)
            for child in children:
                if child != self.scroll:
                    child.move(child.pos().x(),child.pos().y()+diff)
            self.repaint()
        except Exception as error:
            print(error)

    def keyUp(self):
        print('keyUp got emit')
        if self.original:
            self.original = False
            self.scroll.setVisible(True)
            self.move(0,0)
            self.repaint()        

    def config(self):
        try:
            self.scroll.setMaximum(20)
            self.scroll.valueChanged.connect(self.scrolled)
            self.scroll.hide()
            main_paras.keyboard_up.signal.connect(self.keyUp)
            self.back.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.back.clicked.connect(self.close)
            self.save_bt.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.send_bt.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            
            self.save_bt.clicked.connect(self.save_bt_hook)
            self.send_bt.clicked.connect(self.send_bt_hook)
            
            self.email.setText(main_paras.report_email_1)
            self.email_2.setText(main_paras.report_email_2)
        except Exception as error:
            print(error)

    def save_bt_hook(self):
        try:
            main_paras.report_email_1 = self.email.text()
            main_paras.report_email_2 = self.email_2.text()
        except Exception as error:
            print(error)

    def send_bt_hook(self):
        try:
            global popUp
            popUp = wrong_password._WrongPassword()
            email_1 = self.email.text()
            email_2 = self.email_2.text()
            
            if email_1 != '' and email_1.count('@') == 1 and email_2 != '' and email_2.count('@') == 1:
                main_paras.report_email_1 = self.email.text()
                main_paras.report_email_2 = self.email_2.text()
                main_paras.queueForCom.put([TEST_REPORT, email_1, email_2])
                response=main_paras.api_result_que.getTimeout(10)
                if response == None:
                    popUp.setMessage(self.tr("Check network."))
                elif response[1] == API_RESPONSE_FAIL:
                    popUp.setMessage(self.tr(response[3]))
                elif response[1] == API_RESPONSE_SUCCESS:
                    popUp.setMessage(self.tr(response[3]), self.tr('Ok'))
            else:
                popUp.setMessage(self.tr("Enter correct email"))
            x,y = getMainTopLeft()
            popUp.move(x,y)
            popUp.show()
                
        except Exception as error:
            print(error)
            
    def closeEvent(self,event):
        print("_ForgotPassword is closing")


if __name__ == "__main__":
    from PyQt5.QtCore import QTranslator
    import sys
##    trans=QTranslator()
##    trans.load("setting_wrap.qm")
    
    os.environ["QT_IM_MODULE"] = "qtvirtualkeyboard"

    
    app = QtWidgets.QApplication(sys.argv)
##    app.installTranslator(trans)
#    QtGui.QGuiApplication.inputMethod().visibleChanged.connect(handleVisibleChanged)


    QtWidgets.QMainWindow
    window=_TestReport()
    window.move(0,0)
    window.show()
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)
